BankAccountNumberKind enum

The kind of account identifier rendered by BankAccountNumberText.

Each kind selects a display grouping in BankAccountNumberFormatter:

Inheritance
Available extensions

Values

iban → const BankAccountNumberKind

International Bank Account Number (e.g. GB29 NWBK 6016 1331 9268 19).

bban → const BankAccountNumberKind

Basic Bank Account Number: the domestic part of an IBAN.

pan → const BankAccountNumberKind

Primary Account Number: the long card number.

sortCode → const BankAccountNumberKind

UK sort code, displayed as NN-NN-NN.

routing → const BankAccountNumberKind

US ABA routing number, displayed ungrouped.

swiftBic → const BankAccountNumberKind

SWIFT/BIC code, displayed ungrouped.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BankAccountNumberKind>
A constant List of the values in this enum, in order of their declaration.