BankAlertPreference class

Per-event alert preference row data.

Constructors

BankAlertPreference({required BankNotificationType type, bool push = false, bool email = false, bool sms = false, bool locked = false})
const

Properties

email bool
final
hashCode int
The hash code for this object.
no setterinherited
locked bool
Compliance alerts that cannot be disabled: switches render on and disabled with a lock icon.
final
push bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sms bool
final
type BankNotificationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
valueFor(BankAlertChannel channel) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited