BankApplicationStatus enum

The lifecycle status of a product application, from data entry through to the lender's decision.

Inheritance
Available extensions

Values

inProgress → const BankApplicationStatus

The user is still working through the steps.

submitting → const BankApplicationStatus

The application has been sent and is awaiting acknowledgement.

submitted → const BankApplicationStatus

The application was successfully submitted for a decision.

approved → const BankApplicationStatus

The application was approved.

referred → const BankApplicationStatus

The application was referred for manual review.

declined → const BankApplicationStatus

The application was declined.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BankApplicationStatus>
A constant List of the values in this enum, in order of their declaration.