gradient property
Overrides the default avatar gradient. Defaults to BankThemeData.accentGradient; when both are null the avatar is filled with the accent colour.
Implementation
final Gradient? gradient;
Overrides the default avatar gradient. Defaults to BankThemeData.accentGradient; when both are null the avatar is filled with the accent colour.
final Gradient? gradient;