onSubmitted property
Fired with the trimmed text when the user submits the field; the field is cleared afterwards.
Implementation
final ValueChanged<String>? onSubmitted;
Fired with the trimmed text when the user submits the field; the field is cleared afterwards.
final ValueChanged<String>? onSubmitted;