BankBalanceSize enum

The visual size tier for BankBalanceText.

Each tier maps to a different TextStyle from BankTokens:

  • heroBankTokens.numeralHero (44 sp, semi-bold)
  • largeBankTokens.numeralLarge (24 sp, semi-bold)
  • mediumBankTokens.numeralMedium (18 sp, medium)
  • smallBankTokens.numeralSmall (14 sp, medium)
Inheritance
Available extensions

Values

hero → const BankBalanceSize
large → const BankBalanceSize
medium → const BankBalanceSize
small → const BankBalanceSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BankBalanceSize>
A constant List of the values in this enum, in order of their declaration.