BankBill class

A saved biller / upcoming bill.

Constructors

BankBill({required String id, required String billerName, required Money amountDue, required DateTime dueDate, required BankBillStatus status, String? billerLogoUrl, bool eBill = false})
const

Properties

amountDue Money
final
billerLogoUrl String?
final
billerName String
final
dueDate DateTime
final
eBill bool
Paperless bill delivered electronically.
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status BankBillStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override