BankBudget class

Constructors

BankBudget({required String id, required String name, required Money limit, required Money spent, required DateTime periodStart, required DateTime periodEnd, TransactionCategory? category})
const

Properties

category TransactionCategory?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
isOverBudget bool
no setter
limit Money
final
name String
final
periodEnd DateTime
final
periodStart DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spent Money
final
spentFraction double
no setter

Methods

copyWith({String? id, String? name, TransactionCategory? category, Money? limit, Money? spent, DateTime? periodStart, DateTime? periodEnd}) BankBudget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override