BankDeviceKind enum

The hardware class of a signed-in device session.

Inheritance
Available extensions

Values

phone → const BankDeviceKind
tablet → const BankDeviceKind
desktop → const BankDeviceKind
watch → const BankDeviceKind
unknown → const BankDeviceKind

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BankDeviceKind>
A constant List of the values in this enum, in order of their declaration.