BankDocumentDownloadState enum

Download lifecycle of a document row's trailing action.

Inheritance
Available extensions

Values

idle → const BankDocumentDownloadState

No download started: shows the download affordance.

downloading → const BankDocumentDownloadState

Download in flight: shows a circular progress indicator.

done → const BankDocumentDownloadState

Download finished: shows a success check.

failed → const BankDocumentDownloadState

Download failed: shows a danger-coloured retry affordance.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BankDocumentDownloadState>
A constant List of the values in this enum, in order of their declaration.