BankMessageAttachment class

A file attached to a secure message.

Constructors

BankMessageAttachment({required String id, required String fileName, int? sizeBytes, BankAttachmentState state = BankAttachmentState.ready, double? uploadProgress})
const

Properties

fileName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int?
final
state BankAttachmentState
final
uploadProgress double?
0..1 while BankAttachmentState.uploading; indeterminate if null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited