BankNavItem class

A single navigation destination for BankBottomNavBar.

Constructors

BankNavItem({required IconData icon, required String label, IconData? activeIcon})
const

Properties

activeIcon IconData?
Substituted for icon when this item is selected. Falls back to icon.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited