BankNotification class
Constructors
- BankNotification({required String id, required String title, required String body, required DateTime receivedAt, required bool isRead, required BankNotificationType type, String? deepLinkPath, String? imageUrl})
-
const
Properties
- body → String
-
final
- deepLinkPath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- imageUrl → String?
-
final
- isRead → bool
-
final
- receivedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- type → BankNotificationType
-
final
Methods
-
copyWith(
{String? id, String? title, String? body, DateTime? receivedAt, bool? isRead, BankNotificationType? type, String? deepLinkPath, String? imageUrl}) → BankNotification -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override