onBiometric property
When non-null, a fingerprint icon button is shown in the bottom-left position and this callback is invoked on tap.
Implementation
final VoidCallback? onBiometric;
When non-null, a fingerprint icon button is shown in the bottom-left position and this callback is invoked on tap.
final VoidCallback? onBiometric;