pointsBalance property
Current points balance, rendered in hero numerals with locale-style digit grouping converted to the active NumeralStyle.
Implementation
final int pointsBalance;
Current points balance, rendered in hero numerals with locale-style digit grouping converted to the active NumeralStyle.
final int pointsBalance;