onRecurringPatternChanged property
When non-null and BankTransferTiming.recurring is selected, a pattern dropdown is rendered below the segmented button.
Implementation
final ValueChanged<String>? onRecurringPatternChanged;
When non-null and BankTransferTiming.recurring is selected, a pattern dropdown is rendered below the segmented button.
final ValueChanged<String>? onRecurringPatternChanged;