remainingTime property
How much time remains before the session expires. The countdown starts from this value and decrements by one second every tick.
Implementation
final Duration remainingTime;
How much time remains before the session expires. The countdown starts from this value and decrements by one second every tick.
final Duration remainingTime;