amountStyle property
Merged over the highlighted money styles of the hero amount (theme numeralLarge) and the "They receive" row (theme numeralMedium).
Implementation
final TextStyle? amountStyle;
Merged over the highlighted money styles of the hero amount (theme numeralLarge) and the "They receive" row (theme numeralMedium).
final TextStyle? amountStyle;