NumeralStyle enum

Controls which numeral script is used when rendering monetary values.

The NumeralStyleX extension on this enum provides a convert method that translates an already-formatted string (e.g. produced by intl) into the target numeral system.

Inheritance
Available extensions

Values

western → const NumeralStyle

Standard 0-9 digits as used in most Latin-script locales.

easternArabicIndic → const NumeralStyle

Eastern Arabic-Indic digits (٠١٢٣٤٥٦٧٨٩) as used in Arabic-script locales such as Arabic (ar), Persian (fa), and Urdu (ur).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(String input) String

Available on NumeralStyle, provided by the NumeralStyleX extension

Converts the ASCII digits in input to the target numeral script.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NumeralStyle>
A constant List of the values in this enum, in order of their declaration.