accentColor property
Overrides the accent used by the progress fill, slider, spinner, and commit button. Defaults to the theme primary.
Implementation
final Color? accentColor;
Overrides the accent used by the progress fill, slider, spinner, and commit button. Defaults to the theme primary.
final Color? accentColor;