subtitleStyle property
Merged over the computed microtext style (labelSmall, variant color) used under the progress bar and on the maximum row.
Implementation
final TextStyle? subtitleStyle;
Merged over the computed microtext style (labelSmall, variant color) used under the progress bar and on the maximum row.
final TextStyle? subtitleStyle;