accentColor property
Accent for the meter fill, track tint, and increase row. Defaults to the theme primary (warning/danger thresholds still apply).
Implementation
final Color? accentColor;
Accent for the meter fill, track tint, and increase row. Defaults to the theme primary (warning/danger thresholds still apply).
final Color? accentColor;