onAdjust property
Called when the customer taps the increase hint row. When null,
the hint row is static and shows no chevron.
Implementation
final VoidCallback? onAdjust;
Called when the customer taps the increase hint row. When null,
the hint row is static and shows no chevron.
final VoidCallback? onAdjust;