onChanged property
Called when the customer toggles the cushion on or off. When null,
no Switch is shown.
Implementation
final ValueChanged<bool>? onChanged;
Called when the customer toggles the cushion on or off. When null,
no Switch is shown.
final ValueChanged<bool>? onChanged;