BankPerk class

Constructors

BankPerk({required String id, required String partnerName, required String title, required String description, String? logoUrl, String? discountLabel, DateTime? expiresAt, bool isActivated = false})
const

Properties

description String
final
discountLabel String?
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isActivated bool
final
logoUrl String?
final
partnerName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited