BankPlanFeature class
Constructors
-
BankPlanFeature({required String label, required Map<
String, bool?> tierSupport}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tierSupport
→ Map<
String, bool?> -
Maps tierId → true (included) / false (not included) / null (partial).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited