BankScoreBand class

A labeled band on a BankCreditScoreGauge arc.

Constructors

BankScoreBand({required String label, required int upTo, required Color color})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upTo int
Inclusive upper score bound of this band.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited