InstallmentPlan class

Constructors

InstallmentPlan({required int termMonths, required Money monthlyAmount, required Money totalAmount, required bool isInterestFree, double? annualRate, DateTime? startDate})
const

Properties

annualRate → double?
final
hashCode → int
The hash code for this object.
no setteroverride
isInterestFree → bool
final
monthlyAmount → Money
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime?
final
termMonths → int
final
totalAmount → Money
final

Methods

copyWith({int? termMonths, Money? monthlyAmount, Money? totalAmount, bool? isInterestFree, double? annualRate, DateTime? startDate}) → InstallmentPlan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override