AssetQuote class

Constructors

AssetQuote({required String symbol, required String name, required Money price, required double changePercent, Money? change24h, String? logoUrl})
const

Properties

change24h Money?
final
changePercent double
final
hashCode int
The hash code for this object.
no setteroverride
isPositive bool
no setter
logoUrl String?
final
name String
final
price Money
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

copyWith({String? symbol, String? name, Money? price, double? changePercent, Money? change24h, String? logoUrl}) AssetQuote
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override