gainColor property
Overrides the positive tint used by both the price pulse and the change chip. Defaults to BankTokens.investmentGain, or BankTokens.investmentGainDark on a dark surface.
Implementation
final Color? gainColor;
Overrides the positive tint used by both the price pulse and the change chip. Defaults to BankTokens.investmentGain, or BankTokens.investmentGainDark on a dark surface.
final Color? gainColor;