currencyCode property
Currency used to format tooltip, header, and axis values through BankMoneyFormatter. When null, plain numbers are shown.
Implementation
final String? currencyCode;
Currency used to format tooltip, header, and axis values through BankMoneyFormatter. When null, plain numbers are shown.
final String? currencyCode;