addToWatchlistLabel property
Semantics label for the watch toggle when not watched. Defaults to 'Add to watchlist'.
Implementation
final String addToWatchlistLabel;
Semantics label for the watch toggle when not watched. Defaults to 'Add to watchlist'.
final String addToWatchlistLabel;