show static method
Future<void>
show(
- BuildContext context, {
- required SavingsPot pot,
- required Future<
void> onConfirm(- Money amount
- bool isWithdrawal = false,
- Money? availableBalance,
- VoidCallback? onCancel,
Convenience helper to push the sheet as a modal bottom sheet.
Implementation
static Future<void> show(
BuildContext context, {
required SavingsPot pot,
required Future<void> Function(Money) onConfirm,
bool isWithdrawal = false,
Money? availableBalance,
VoidCallback? onCancel,
}) =>
BankSheet.show<void>(
context,
// The sheet body paints its own ground and handle.
backgroundColor: Colors.transparent,
showHandle: false,
builder: (_) => BankPotContributionSheet(
pot: pot,
isWithdrawal: isWithdrawal,
availableBalance: availableBalance,
onConfirm: onConfirm,
onCancel: onCancel,
),
);