semanticLabel property
Overrides the card semantics. Defaults to a label built from the title, progress, and streak.
Implementation
final String? semanticLabel;
Overrides the card semantics. Defaults to a label built from the title, progress, and streak.
final String? semanticLabel;