itemBuilder property
When non-null, completely overrides the card content. Receives the BuildContext and the SavingsPot and must return a widget tree that fills the card.
Implementation
final Widget Function(BuildContext, SavingsPot)? itemBuilder;
When non-null, completely overrides the card content. Receives the BuildContext and the SavingsPot and must return a widget tree that fills the card.
final Widget Function(BuildContext, SavingsPot)? itemBuilder;