semanticLabel property
Overrides the tile semantics. Defaults to a label built from the merchant, amount, and initiator.
Implementation
final String? semanticLabel;
Overrides the tile semantics. Defaults to a label built from the merchant, amount, and initiator.
final String? semanticLabel;