amountStyle property
Merged over the computed hero pot amount style (BankThemeData.numeralLarge in onSurface).
Implementation
final TextStyle? amountStyle;
Merged over the computed hero pot amount style (BankThemeData.numeralLarge in onSurface).
final TextStyle? amountStyle;