dueLabel property
Label inside the due pill shown while the user's contribution is still owed this cycle. Defaults to 'Due'.
Implementation
final String dueLabel;
Label inside the due pill shown while the user's contribution is still owed this cycle. Defaults to 'Due'.
final String dueLabel;