BankAccount class
Constructors
-
BankAccount({required String id, required String name, required String maskedNumber, required Money balance, required BankAccountStatus status, required BankAccountType type, required String currencyCode, String? ibanOrAccountNumber, String? sortCodeOrBic, List<
String> ? ownerIds}) -
const
Properties
- balance → Money
-
final
- currencyCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- ibanOrAccountNumber → String?
-
final
- id → String
-
final
- maskedNumber → String
-
final
- name → String
-
final
-
ownerIds
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortCodeOrBic → String?
-
final
- status → BankAccountStatus
-
final
- type → BankAccountType
-
final
Methods
-
copyWith(
{String? id, String? name, String? maskedNumber, Money? balance, BankAccountStatus? status, BankAccountType? type, String? currencyCode, String? ibanOrAccountNumber, String? sortCodeOrBic, List< String> ? ownerIds}) → BankAccount -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override