BankAddress class
An immutable postal address captured by BankAddressForm.
Constructors
- BankAddress({required String line1, required String city, required String postalCode, required BankCountry country, String? line2, String? region})
-
const
Properties
- city → String
-
final
- country → BankCountry
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- line1 → String
-
final
- line2 → String?
-
final
- postalCode → String
-
final
- region → String?
-
State / province / emirate, when the country uses one.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? line1, String? line2, String? city, String? region, String? postalCode, BankCountry? country}) → BankAddress -
displayLines(
) → List< String> - Lines in the country's conventional display order.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override