BankBeneficiary class
Constructors
- BankBeneficiary({required String id, required String name, required String maskedAccount, required BeneficiaryType type, required bool isVerified, String? avatarUrl, String? bankName, String? currencyCode})
-
const
Properties
- avatarUrl → String?
-
final
- bankName → String?
-
final
- currencyCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isVerified → bool
-
final
- maskedAccount → String
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → BeneficiaryType
-
final
Methods
-
copyWith(
{String? id, String? name, String? maskedAccount, BeneficiaryType? type, String? avatarUrl, String? bankName, String? currencyCode, bool? isVerified}) → BankBeneficiary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override