BankConsent class
A granted open-banking / data-sharing consent.
Constructors
-
BankConsent({required String id, required String granteeName, required List<
String> scopes, required DateTime grantedAt, required BankConsentState state, String? granteeLogoUrl, DateTime? expiresAt}) -
const
Properties
- expiresAt → DateTime?
-
final
- grantedAt → DateTime
-
final
- granteeLogoUrl → String?
-
final
- granteeName → String
-
The third party holding access, e.g.
'Budgeting App X'.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
Human-readable scope descriptions, e.g.
'Account balances'.final - state → BankConsentState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited