BankInsight class
Constructors
- BankInsight({required String id, required String title, required String body, required InsightConfidence confidence, required DateTime generatedAt, required bool isDismissed, })
-
const
Properties
- body → String
-
final
- confidence → InsightConfidence
-
final
- generatedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isDismissed → bool
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
copyWith(
{String? id, String? title, String? body, InsightConfidence? confidence, DateTime? generatedAt, bool? isDismissed, }) → BankInsight -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override