BankTransactionCostSplitSheet class
Split the cost of a single transaction between multiple people.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BankTransactionCostSplitSheet
Constructors
-
BankTransactionCostSplitSheet({required Transaction transaction, required List<
BankSplitParticipant> participants, required ValueChanged<Map< onConfirm, Key? key, BorderRadius? radius, Color? backgroundColor, Color? handleColor, Color? accentColor, Color? avatarBackgroundColor, TextStyle? titleStyle, double? maxHeightFraction, IconData? closeIcon, String title = 'Split Cost', String totalLabel = 'Total: ', String allocatedLabel = 'Allocated', Duration? animationDuration, Curve? animationCurve})String, Money> > -
const
Properties
- accentColor → Color?
-
Overrides the primary accents (active toggle, initials, confirm
button). Defaults to the theme primary.
final
- allocatedLabel → String
-
Overrides the running total label. Defaults to 'Allocated'.
final
- animationCurve → Curve?
-
Overrides the toggle animation curve. Defaults to
BankTokens.curveStandard.
final
- animationDuration → Duration?
-
Overrides the toggle animation duration. Defaults to
BankTokens.durationFast.
final
- avatarBackgroundColor → Color?
-
Overrides the participant avatar background. Defaults to the theme
surfaceVariant.
final
- backgroundColor → Color?
-
Overrides the sheet background. Defaults to the theme surface.
final
- closeIcon → IconData?
-
Overrides the close button glyph. Defaults to Icons.close.
final
- handleColor → Color?
-
Overrides the drag handle color. Defaults to the theme outline.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxHeightFraction → double?
-
Overrides the max sheet height as a screen fraction. Defaults to
0.88.
final
-
onConfirm
→ ValueChanged<
Map< String, Money> > -
Called when the user confirms; maps participantId → allocated Money.
final
-
participants
→ List<
BankSplitParticipant> -
final
- radius → BorderRadius?
-
Overrides the sheet corner radius. Defaults to the theme sheetRadius.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Overrides the sheet title. Defaults to 'Split Cost'.
final
- titleStyle → TextStyle?
-
Merged over the sheet title style (BankTokens.headlineSmall).
final
- totalLabel → String
-
Overrides the total prefix. Defaults to 'Total: '.
final
- transaction → Transaction
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BankTransactionCostSplitSheet> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {required Transaction transaction, required List< BankSplitParticipant> participants, required ValueChanged<Map< onConfirm}) → Future<String, Money> >void> - Convenience helper to push the sheet.