BankPlanTier class
Constructors
-
BankPlanTier({required String id, required String name, required Money monthlyPrice, required List<
BankPlanFeature> features, String? tagline, BankCardMaterial? material, Color? accentColor}) -
const
Properties
- accentColor → Color?
-
final
-
features
→ List<
BankPlanFeature> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- material → BankCardMaterial?
-
final
- monthlyPrice → Money
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagline → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited