BankCurrencyWallet class
Data for a single currency wallet tab.
Constructors
- BankCurrencyWallet({required String currencyCode, required String currencyName, required Money balance, String? flagEmoji})
-
const
Properties
- balance → Money
-
Current balance held in this currency.
final
- currencyCode → String
-
ISO 4217 currency code, e.g.
'GBP'.final - currencyName → String
-
Human-readable currency name, e.g.
'British Pound'.final - flagEmoji → String?
-
Optional flag emoji, e.g.
'🇬🇧'. Displayed before the currency code.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited