ExchangeRate class
Constructors
- ExchangeRate({required String fromCurrency, required String toCurrency, required Decimal rate, required DateTime fetchedAt})
-
const
Properties
- fetchedAt → DateTime
-
final
- fromCurrency → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- rate → Decimal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toCurrency → String
-
final
Methods
-
convert(
Money from) → Money -
copyWith(
{String? fromCurrency, String? toCurrency, Decimal? rate, DateTime? fetchedAt}) → ExchangeRate -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override