Holding class
Constructors
Properties
- assetClass → AssetClass
-
final
- assetId → String
-
final
- currentValue → Money
-
final
- gainLoss → Money
-
final
- gainLossPercent → double
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isGain → bool
-
no setter
- logoUrl → String?
-
final
- name → String
-
final
- quantity → Decimal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
final
Methods
-
copyWith(
{String? assetId, String? symbol, String? name, AssetClass? assetClass, Decimal? quantity, Money? currentValue, Money? gainLoss, double? gainLossPercent, String? logoUrl}) → Holding -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override