shadow property

List<BoxShadow>? shadow
final

Overrides the card shadow. Defaults to the theme glow when enabled, else the resting card shadow for the ambient background brightness (BankTokens.shadowCardFor); pass const [] to flatten.

Implementation

final List<BoxShadow>? shadow;