BankSharedPotInvite class
Invite another account holder to view or contribute to a pot.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BankSharedPotInvite
Constructors
-
const
Properties
- accentColor → Color?
-
Overrides the invite row and initials accent. Defaults to the
theme primary colour.
final
-
currentMembers
→ List<
BankPotMember> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteIcon → IconData?
-
Overrides the invite row glyph. Defaults to
Icons.person_add_alt_1_outlined.
final
- inviteLabel → String
-
Caption of the invite row. Defaults to 'Invite someone'.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- memberSemanticTemplate → String
-
Member row semantics template;
{name}is substituted. Defaults to 'Member: {name}'.final - onInvite → VoidCallback?
-
final
-
onRemoveMember
→ Future<
void> Function(String memberId)? -
final
- padding → EdgeInsetsGeometry?
-
Overrides the heading padding. Defaults to space4 by space3.
final
- pot → SavingsPot
-
final
- removeIcon → IconData?
-
Overrides the remove button glyph. Defaults to Icons.close.
final
- removeMemberTooltip → String
-
Tooltip on each member's remove button. Defaults to
'Remove member'.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Heading above the member list. Defaults to 'Members'.
final
- titleStyle → TextStyle?
-
Merged over the computed heading style (BankTokens.labelLarge
in onSurface).
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited