SavingsPot class

Constructors

SavingsPot({required String id, required String name, required Money target, required Money current, required bool hasOwnAccountNumber, required List<String> memberIds, required bool isRoundUpDestination, double? interestRate, String? imageUrl, DateTime? targetDate})
const

Properties

current Money
final
hashCode int
The hash code for this object.
no setteroverride
hasOwnAccountNumber bool
final
id String
final
imageUrl String?
final
interestRate double?
final
isRoundUpDestination bool
final
memberIds List<String>
final
name String
final
progressFraction double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Money
final
targetDate DateTime?
final

Methods

copyWith({String? id, String? name, Money? target, Money? current, double? interestRate, bool? hasOwnAccountNumber, String? imageUrl, List<String>? memberIds, DateTime? targetDate, bool? isRoundUpDestination}) SavingsPot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override